@@ -149,6 +149,14 @@ my $WARN_FILE_TYPE =  Lintian::Data->new(
         };
     });
 
+# prebuilt-file or forbidden file type
+my $RFC_WHITELIST =  Lintian::Data->new(
+    'cruft/rfc-whitelist',
+    qr/\s*\~\~\s*/,
+    sub {
+        return qr/$_[0]/xms;
+    });
+
 my $MISSING_DIR_SEARCH_PATH
   =  Lintian::Data->new('cruft/missing-dir-search-path');
 
@@ -167,9 +175,11 @@ sub _get_license_check_file {
         $filename,
         qr/\s*\~\~\s*/,
         sub {
-            my %LICENSE_CHECK_DISPATCH_TABLE
-              = ('license-problem-gfdl-invariants' =>
-                  \&_check_gfdl_license_problem,);
+            my %LICENSE_CHECK_DISPATCH_TABLE= (
+                'license-problem-gfdl-invariants' =>
+                  \&_check_gfdl_license_problem,
+                'rfc-whitelist-filename' =>\&_rfc_whitelist_filename,
+            );
             my @splitline = split(/\s*\~\~\s*/, $_[1], 5);
             my $syntaxerror = 'Syntax error in '.$filename;
             if(scalar(@splitline) > 5 or scalar(@splitline) <2) {
@@ -778,7 +788,7 @@ sub full_text_check {
     # some js file comments are really really long
     my $sfd
       = Lintian::SlidingWindow->new($fd, \&lc_block,
-        _is_javasript_but_not_minified($name) ? 8092 : 4096);
+        _is_javascript_but_not_minified($name) ? 8092 : 4096);
     my %licenseproblemhash;
 
     # we try to read this file in block and use a sliding window
@@ -792,8 +802,10 @@ sub full_text_check {
 
         if(
             _license_check(
-                $source_pkg, $name,$NON_DISTRIBUTABLE_LICENSES,$block,
-                $blocknumber,\$cleanedblock,\%matchedkeyword,
+                $source_pkg, $name,
+                $basename,$NON_DISTRIBUTABLE_LICENSES,
+                $block,$blocknumber,
+                \$cleanedblock,\%matchedkeyword,
                 \%licenseproblemhash
             )
           ){
@@ -806,9 +818,11 @@ sub full_text_check {
             next BLOCK;
         }
 
-        _license_check($source_pkg, $name, $NON_FREE_LICENSES,
-            $block,  $blocknumber,\$cleanedblock, \%matchedkeyword,
-            \%licenseproblemhash);
+        _license_check(
+            $source_pkg, $name, $basename,
+            $NON_FREE_LICENSES,$block,  $blocknumber,
+            \$cleanedblock, \%matchedkeyword,\%licenseproblemhash
+        );
 
         # check only in block 0
         if($blocknumber == 0) {
@@ -821,7 +835,7 @@ sub full_text_check {
 }
 
 # check if file is javascript but not minified
-sub _is_javasript_but_not_minified {
+sub _is_javascript_but_not_minified {
     my ($name) = @_;
     my $isjsfile = ($name =~ m/\.js$/) ? 1 : 0;
     if($isjsfile) {
@@ -835,7 +849,7 @@ sub _is_javasript_but_not_minified {
 sub _search_in_block0 {
     my ($entry, $info, $name, $basename, $dirname, $path, $block) = @_;
 
-    if(_is_javasript_but_not_minified($name)) {
+    if(_is_javascript_but_not_minified($name)) {
         # exception sphinx documentation
         if($basename eq 'searchindex.js') {
             if($block =~ m/\A\s*search\.setindex\s* \s* \(\s*\{/xms) {
@@ -849,6 +863,7 @@ sub _search_in_block0 {
             if($block =~ m/(?:\A|\v)\s*var\s+deployJava\s*=\s*function/xmsi) {
                 check_missing_source($entry,$info,$name,$basename,$dirname,
                     [['(?i)\.js$','.txt'],['','']]);
+                return;
             }
         }
         # now search hidden minified
@@ -894,9 +909,11 @@ sub _tag_gfdl {
 
 # return True in case of license problem
 sub _check_gfdl_license_problem {
-    my ($name,$block,$blocknumber,$cleanedblock,$matchedkeyword,
-        $licenseproblemhash,%matchedhash)
-      = @_;
+    my (
+        $name,$basename,$block,
+        $blocknumber,$cleanedblock,$matchedkeyword,
+        $licenseproblemhash,$licenseproblem,%matchedhash
+    )= @_;
     my $rawgfdlsections  = $matchedhash{rawgfdlsections}  || '';
     my $rawcontextbefore = $matchedhash{rawcontextbefore} || '';
 
@@ -904,25 +921,28 @@ sub _check_gfdl_license_problem {
     my $gfdlsections  = _strip_punct($rawgfdlsections);
     my $contextbefore = _strip_punct($rawcontextbefore);
 
+    my $oldgfdlsections;
     # remove classical and without meaning part of
     # matched string
-    $gfdlsections =~ s{ \A \(?[ ]? g?fdl [ ]?\)?[ ]? [,\.;]?[ ]?}{}xismo;
-    $gfdlsections =~ s{ \A (?:either[ ])?
-                           version [ ] \d+(?:\.\d+)? [ ]?}{}xismo;
-    $gfdlsections =~ s{ \A of [ ] the [ ] license [ ]?[,\.;][ ]?}{}xismo;
-    $gfdlsections =~ s{ \A or (?:[ ]\(?[ ]? at [ ] your [ ] option [ ]?\)?)?
-                           [ ] any [ ] later [ ] version[ ]?}{}xismo;
-    $gfdlsections =~ s{ \A published [ ] by [ ]
-                           the [ ] free [ ] software [ ] foundation[ ]?}{}xismo;
-    $gfdlsections =~ s{\(?[ ]?FSF[ ]?\)?[ ]?}{}xismo;
-    $gfdlsections =~ s{[,\.;]?[ ]?}{}xismo;
-    $contextbefore =~ s{
-                          [ ]? (:?[,\.;]? [ ]?)?
-                           permission [ ] is [ ] granted [ ] to [ ] copy [ ]?[,\.;]?[ ]?
-                           distribute [ ]?[,\.;]?[ ]? and[ ]?/?[ ]?or [ ] modify [ ]
-                           this [ ] document [ ] under [ ] the [ ] terms [ ] of [ ] the\Z}
-                        {}xismo;
+    do {
+        $oldgfdlsections = $gfdlsections;
+        $gfdlsections =~ s{ \A \(?[ ]? g?fdl [ ]?\)?[ ]? [,\.;]?[ ]?}{}xsmo;
+        $gfdlsections =~ s{ \A (?:either[ ])?
+                           version [ ] \d+(?:\.\d+)? [ ]?}{}xsmo;
+        $gfdlsections =~ s{ \A of [ ] the [ ] license [ ]?[,\.;][ ]?}{}xsmo;
+        $gfdlsections=~ s{ \A or (?:[ ]\(?[ ]? at [ ] your [ ] option [ ]?\)?)?
+                           [ ] any [ ] later [ ] version[ ]?}{}xsmo;
+        $gfdlsections =~ s{ \A (as[ ])? published [ ] by [ ]
+                           the [ ] free [ ] software [ ] foundation[ ]?}{}xsmo;
+        $gfdlsections =~ s{\(?[ ]? fsf [ ]?\)?[ ]?}{}xsmo;
+        $gfdlsections =~ s{\A [ ]? [,\.;]? [ ]?}{}xsmo;
+    } while ($oldgfdlsections ne $gfdlsections);
 
+    $contextbefore =~ s{
+                       [ ]? (:?[,\.;]? [ ]?)?
+                       permission [ ] is [ ] granted [ ] to [ ] copy [ ]?[,\.;]?[ ]?
+                       distribute [ ]?[,\.;]?[ ]? and[ ]?/?[ ]?or [ ] modify [ ]
+                       this [ ] document [ ] under [ ] the [ ] terms [ ] of [ ] the\Z}{}xsmo;
     # Treat ambiguous empty text
     unless(
         defined(
@@ -990,6 +1010,25 @@ sub _check_gfdl_license_problem {
     return 1;
 }
 
+# whitelist good rfc
+sub _rfc_whitelist_filename {
+    my (
+        $name,$basename,$block,
+        $blocknumber,$cleanedblock,$matchedkeyword,
+        $licenseproblemhash,$licenseproblem,%matchedhash
+    )= @_;
+    my $lcname = lc($basename);
+
+    foreach my $rfc_regexp ($RFC_WHITELIST->all) {
+        my $regex = $RFC_WHITELIST->value($rfc_regexp);
+        if($lcname =~ m/$regex/xms) {
+            return 0;
+        }
+    }
+    tag $licenseproblem, $name;
+    return 1;
+}
+
 sub _clean_block {
     my ($text) = @_;
 
@@ -1009,7 +1048,7 @@ sub _clean_block {
     $text =~ s/\"\s?\v\#~\s?\"//gxms;
 
     $text =~ s/\\url{[^}]*?}/ /gxms;          # (la)?tex url
-    $text =~ s/\emph{/ /gxms;                 # (la)?tex emph
+    $text =~ s/\\emph{/ /gxms;                 # (la)?tex emph
     $text =~ s/\\href{[^}]*?}
                      {([^}]*?)}/ $1 /gxms;    # (la)?tex href
     $text =~ s/\\hyperlink
@@ -1129,9 +1168,11 @@ sub _md5sum_based_check {
 
 # check bad license
 sub _license_check {
-    my ($source_pkg, $name, $licensesdatas, $block, $blocknumber,
-        $cleanedblock,$matchedkeyword, $licenseproblemhash)
-      = @_;
+    my (
+        $source_pkg, $name, $basename,
+        $licensesdatas, $block, $blocknumber,
+        $cleanedblock,$matchedkeyword, $licenseproblemhash
+    )= @_;
     my $ret = 0;
 
     # avoid to check lintian
@@ -1176,8 +1217,9 @@ sub _license_check {
 
         if(defined($licenseproblemdata->{'callsub'})) {
             my $subresult= $licenseproblemdata->{'callsub'}->(
-                $name, $block,$blocknumber,$cleanedblock,$matchedkeyword,
-                $licenseproblemhash,%+
+                $name, $basename, $block,
+                $blocknumber,$cleanedblock,$matchedkeyword,
+                $licenseproblemhash,$licenseproblem,%+
             );
             if($subresult) {
                 $licenseproblemhash->{$licenseproblem} = 1;
