@@ -23,8 +23,6 @@ use strict;
 use warnings;
 use autodie;
 
-use File::Basename;
-
 use Lintian::Data;
 use Lintian::Output qw(warning);
 use Lintian::Tags qw(tag);
@@ -74,6 +72,10 @@ my $PRIVACY_BREAKER_TAG_ATTR= Lintian::Data->new(
         };
     });
 
+my $PKG_CONFIG_BAD_REGEX
+  = Lintian::Data->new('files/pkg-config-bad-regex',qr/~~~~~/,
+    sub { return  qr/$_[0]/xsm;});
+
 my $COMPRESS_FILE_EXTENSIONS
   = Lintian::Data->new('files/compressed-file-extensions',
     qr/\s++/,sub { return qr/\Q$_[0]\E/ });
@@ -137,7 +139,8 @@ sub _load_file_package_list_mapping {
     };
 }
 
-my $JS_EXT = '(?:(?i)[-._]?(?:compiled|lite|min|pack(?:ed)?)?\.js(?:\.gz)?)$';
+my $JS_EXT
+  = '(?:(?i)[-._]?(?:compiled|lite|min|pack(?:ed)?|yc)?\.js(?:\.gz)?)$';
 my $PHP_EXT = '(?i)\.(?:php|inc|dtd)$';
 my @FILE_PACKAGE_MAPPING = (
     _load_file_package_list_mapping(
@@ -571,18 +574,43 @@ sub run {
             }
             # ---------------- arch-indep pkconfig
             elsif ($file->is_regular_file
-                && $fname =~ m,^usr/(?:lib|share)/pkgconfig/[^/]+\.pc$,) {
-                open(my $fd, '<', $info->unpacked($file));
-              LINE:
-                while (my $line = <$fd>) {
+                && $fname
+                =~ m,^usr/(?:lib(/[^/]+)?|share)/pkgconfig/[^/]+\.pc$,) {
+                my $pkg_config_arch = $1 // '';
+                $pkg_config_arch =~ s,\A/,,ms;
+
+                open(my $fd, '<:raw', $info->unpacked($file));
+                my $sfd = Lintian::SlidingWindow->new($fd);
+              BLOCK:
+                while (my $block = $sfd->readwindow()) {
+                    # remove comment line
+                    $block =~ s,\#\V*,,gsm;
+                    # remove continuation line
+                    $block =~ s,\\\n, ,gxsm;
                     # check if pkgconfig file include path point to
                     # arch specific dir
+                  MULTI_ARCH_DIR:
                     foreach my $multiarch_dir ($MULTIARCH_DIRS->all) {
-                        my $regex
-                          = $MULTIARCH_DIRS->value($multiarch_dir)->{'match'};
-                        if ($line =~ m{$regex}) {
-                            tag 'pkg-config-multi-arch-wrong-dir',$file;
-                            last LINE;
+                        my $value =  $MULTIARCH_DIRS->value($multiarch_dir);
+                        my $pkgconfig_dir = $value->{'dir'};
+                        my $regex = $value->{'match'};
+                        if ($pkg_config_arch eq $pkgconfig_dir) {
+                            next MULTI_ARCH_DIR;
+                        }
+                        if ($block =~ m{$regex}) {
+                            tag 'pkg-config-multi-arch-wrong-dir',$file,
+                              'full text contains architecture specific dir',
+                              $pkgconfig_dir;
+                            last MULTI_ARCH_DIR;
+                        }
+                    }
+                  PKG_CONFIG_TABOO:
+                    foreach my $taboo ($PKG_CONFIG_BAD_REGEX->all) {
+                        my $regex = $PKG_CONFIG_BAD_REGEX->value($taboo);
+                        while($block =~ m{$regex}xmsg) {
+                            my $extra = $1 // '';
+                            $extra =~ s/\s+/ /g;
+                            tag 'pkg-config-bad-directive', $file, $extra;
                         }
                     }
                 }
@@ -694,6 +722,15 @@ sub run {
             elsif ($fname =~ m,^usr/share/mime/[^/]+$,) {
                 tag 'package-contains-mime-cache-file', $file;
             }
+            # ---------------- /usr/share/p11-kit/modules
+            elsif (
+                   $fname =~ m{^usr/share/p11-kit/modules/.}
+                && $fname !~ m{\A usr/share/p11-kit/modules/
+                                  [[:alnum:]][[:alnum:]_.-]*\.module\Z
+                              }xsm
+              ) {
+                tag 'incorrect-naming-of-pkcs11-module', $file;
+            }
             # ---------------- /usr/share/vim
             elsif ($fname =~ m,^usr/share/vim/vim(?:current|\d{2})/([^/]++),){
                 my $is_vimhelp = $1 eq 'doc' && $pkg =~ m,^vimhelp-\w++$,;
@@ -1529,6 +1566,9 @@ sub run {
             if ($fname =~ m,/\.xvpics/?$,) {
                 tag 'package-contains-xvpics-dir', $file;
             }
+            if ($fname =~ m,/\.thumbnails/?$,) {
+                tag 'package-contains-thumbnails-dir', $file;
+            }
             if ($fname =~ m,usr/share/doc/[^/]+/examples/examples/?$,) {
                 tag 'nested-examples-directory', $file;
             }
