@@ -218,7 +218,7 @@ sub run {
         tag 'deprecated-kdelnk-file', $file if ($file =~ m,\.kdelnk$,);
 
         if (   $file->is_file
-            && $file =~ m,^usr/share/applications/.*\.desktop$,) {
+            && $file =~ m,^usr/share/(?:applications|xsessions)/.*\.desktop$,){
 
             if ($operm & 0111) {
                 tag 'executable-desktop-file', sprintf('%s %04o',$file,$operm);
@@ -451,8 +451,8 @@ sub verify_line {
       unless ($okay
         or not $command
         or ($tested_packages >= 2)
-        or ($section =~ m:^(WindowManagers/Modules|FVWM Modules|Window Maker):)
-      );
+        or
+        ($section =~ m:^(WindowManagers/Modules|FVWM Modules|Window Maker):));
 
     if (exists($vals{'icon'})) {
         verify_icon($info, $proc, $group, $menufile, $fullname, $linecount,
